@@ -203,7 +203,7 @@ exo_binding_on_disconnect (gpointer  data,
   ExoBindingLink *blink = data;
   ExoBinding     *binding;
 
-  binding = (ExoBinding *) (((gchar *) blink) - G_STRUCT_OFFSET (ExoBinding, blink));
+  binding = (ExoBinding *) (gpointer) (((gchar *) blink) - G_STRUCT_OFFSET (ExoBinding, blink));
 
   if (binding->destroy != NULL)
     binding->destroy (blink->user_data);
@@ -225,7 +225,7 @@ exo_mutual_binding_on_disconnect_object1 (gpointer  data,
   ExoBindingLink   *blink = data;
   GObject          *object2;
 
-  binding = (ExoMutualBinding *) (((gchar *) blink) - G_STRUCT_OFFSET (ExoMutualBinding, direct));
+  binding = (ExoMutualBinding *) (gpointer) (((gchar *) blink) - G_STRUCT_OFFSET (ExoMutualBinding, direct));
   binding->reverse.dst_object = NULL;
 
   object2 = binding->direct.dst_object;
@@ -250,7 +250,7 @@ exo_mutual_binding_on_disconnect_object2 (gpointer  data,
   ExoBindingLink   *blink = data;
   GObject          *object1;
 
-  binding = (ExoMutualBinding *) (((gchar *) blink) - G_STRUCT_OFFSET (ExoMutualBinding, reverse));
+  binding = (ExoMutualBinding *) (gpointer) (((gchar *) blink) - G_STRUCT_OFFSET (ExoMutualBinding, reverse));
   binding->direct.dst_object = NULL;
 
   object1 = binding->reverse.dst_object;
