@@ -27,6 +27,12 @@
 #include <string.h>
 #endif
 
+#include <gdk/gdk.h>
+
+#ifdef GDK_WINDOWING_WAYLAND
+#include <gdk/gdkwayland.h>
+#endif
+
 #include <exo/exo-gtk-extensions.h>
 #include <exo/exo-private.h>
 #include <exo/exo-thumbnail-preview.h>
@@ -283,5 +289,106 @@ exo_gtk_dialog_add_secondary_button (GtkDialog *dialog,
 
 
 
+static void
+exo_gtk_get_work_area_dimensions (GdkWindow    *window,
+                                  GdkRectangle *dimensions)
+{
+  GdkDisplay   *display;
+  GdkRectangle  geometry;
+
+  GdkMonitor   *monitor;
+
+  display = gdk_window_get_display (window);
+  monitor = gdk_display_get_monitor_at_window (display, window);
+  gdk_monitor_get_workarea (monitor, &geometry);
+
+  if (dimensions != NULL)
+    {
+       dimensions->x = geometry.x;
+       dimensions->y = geometry.y;
+       dimensions->width = geometry.width;
+       dimensions->height = geometry.height;
+    }
+}
+
+
+
+/**
+ * exo_gtk_position_search_box:
+ * @view : The view which owns the search box
+ * @search_dialog : The type-ahead search box
+ * @user_data : Unused, though required in order to fit the expected callback signature
+ *
+ * Function to position the type-ahead search box below a view
+ * The function usually will be used as callback.
+ **/
+void
+exo_gtk_position_search_box (GtkWidget *view,
+                             GtkWidget *search_dialog,
+                             gpointer   user_data)
+{
+  GtkRequisition requisition;
+  GdkWindow     *view_window = gtk_widget_get_window (view);
+  GdkRectangle   work_area_dimensions;
+  gint           view_width, view_height;
+  gint           view_x, view_y;
+  gint           x, y;
+  GdkDisplay    *display;
+  GdkRectangle   monitor_dimensions;
+  GdkMonitor    *monitor;
+
+  /* make sure the search dialog is realized */
+  gtk_widget_realize (search_dialog);
+
+  gdk_window_get_origin (view_window, &view_x, &view_y);
+  view_width = gdk_window_get_width (view_window);
+  view_height = gdk_window_get_height (view_window);
+
+  /* FIXME: make actual use of new Gtk3 layout system */
+  gtk_widget_get_preferred_width (search_dialog, NULL, &requisition.width);
+  gtk_widget_get_preferred_height (search_dialog, NULL, &requisition.height);
+
+  exo_gtk_get_work_area_dimensions (view_window, &work_area_dimensions);
+
+#ifdef GDK_WINDOWING_WAYLAND
+  if (GDK_IS_WAYLAND_DISPLAY (gdk_display_get_default ()))
+    x = view_x + view_width - requisition.width;
+  else
+#endif
+  if (view_x + view_width > work_area_dimensions.x + work_area_dimensions.width)
+    x = work_area_dimensions.x + work_area_dimensions.width - requisition.width;
+  else if (view_x + view_width - requisition.width < work_area_dimensions.x)
+    x = work_area_dimensions.x;
+  else
+    x = view_x + view_width - requisition.width;
+
+#ifdef GDK_WINDOWING_WAYLAND
+  if (GDK_IS_WAYLAND_DISPLAY (gdk_display_get_default ()))
+      y = view_y + view_height - requisition.height;
+  else
+#endif
+  if (view_y + view_height > work_area_dimensions.y + work_area_dimensions.height)
+    y = work_area_dimensions.y + work_area_dimensions.height - requisition.height;
+  else if (view_y + view_height < work_area_dimensions.y)
+    y = work_area_dimensions.y;
+  else
+    y = view_y + view_height - requisition.height;
+
+  display = gdk_window_get_display (view_window);
+  if (display)
+    {
+      monitor = gdk_display_get_monitor_at_window (display, view_window);
+      if (monitor)
+        {
+          gdk_monitor_get_geometry (monitor, &monitor_dimensions);
+          if (y + requisition.height > monitor_dimensions.height)
+            y = monitor_dimensions.height - requisition.height;
+        }
+    }
+
+  gtk_window_move (GTK_WINDOW (search_dialog), x, y);
+}
+
+
 #define __EXO_GTK_EXTENSIONS_C__
 #include <exo/exo-aliasdef.c>
