@@ -25,6 +25,11 @@
 #include <stdlib.h>
 #endif
 
+/* prevent g_test_init from aborting */
+#ifdef G_DISABLE_ASSERT
+#undef G_DISABLE_ASSERT
+#endif
+
 #include <exo/exo.h>
 
 
